@@ -5,16 +5,16 @@
 
 typedef VAR_    STRINGVAR_;
 
-STRINGVAR_  stringConstructor(void);
-STRINGVAR_  stringConstructor_cP(char const *str);
+STRINGVAR_  *stringConstructor(void);
+STRINGVAR_  *stringConstructor_cP(char const *str);
 void        stringDestructor(STRINGVAR_ *var);
-STRINGVAR_  stringCopyCons(STRINGVAR_ const *var);
+STRINGVAR_  *stringCopyCons(STRINGVAR_ const *var);
 
 void        stringAssign(STRINGVAR_ *lhs, STRINGVAR_ const *rhs);
 
 void        stringAdd(STRINGVAR_ *lhs, STRINGVAR_ const *rhs);
 int         stringLogical(STRINGVAR_ const *lhs);
 
-char const *stringStr(STRINGVAR_ const *lhs);
+char        *stringStr(STRINGVAR_ const *lhs);  /* const removed */
 
 #endif
