@@ -1,6 +1,6 @@
 #include <ctype.h>
 #include "../rss/icrssdef.h"
-#include "../icm.h"
+#include "../rss/icm.h"
 
 typedef enum
 {
@@ -77,3 +77,4 @@ void pushback(int ch);
 void pushfile (char *);
 void skipblanks(void);
 char *skip_until(char *cp);
+void undef(char *cp);
